<template>
  <component :is="userData === undefined ? 'div' : 'b-card'">

    <!-- Alert: No item found -->
    <b-alert
      variant="danger"
      :show="userData === undefined"
    >
      <h4 class="alert-heading">
        帳號數據出現異常
      </h4>
      <div class="alert-body">
        找不到該用戶
        <b-link
          class="alert-link"
          :to="{ name: 'information-users-list'}"
        >
          列表
        </b-link>
        其他用戶
      </div>
    </b-alert>
      
    <b-tabs v-if="userData">
      <user-edit-tab-account :user-data="userData" class="mt-2 pt-75"/>
    </b-tabs>
  </component>
</template>

<script>
import { ref, onUnmounted } from '@vue/composition-api'
import router from '@/router'
import store from '@/store'
import userStoreModule from '../userStoreModule'
import UserEditTabAccount from './UserEditTabAccount.vue'
import UserEditTabInformation from './UserEditTabInformation.vue'
import UserEditTabSocial from './UserEditTabSocial.vue'
import axios from 'axios'

export default {
  components: {
    UserEditTabAccount,
    UserEditTabInformation,
    UserEditTabSocial,
  },
  setup() {
    const userData = ref(null)
    axios
      .get('/api/v1/users/show/'+router.currentRoute.params.id)
      .then(response => { 
       userData.value = response.data.data
      })
      .catch(error => {
        if (error.response.status === 404) {
          userData.value = undefined
        }
      })

    return {
      userData,
    }
  },
}
</script>

<style>

</style>
